Processor.App.processor_utils.PipeMetadata — CommonCrawl Extractor 1.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# Processor.App.processor_utils.PipeMetadata

class Processor.App.processor_utils.PipeMetadata(domain_record: ~Processor.App.processor_utils.DomainRecord, article_data: ~typing.Dict[~typing.Any, ~typing.Any] = <factory>, warc_header: ~typing.Dict[str, ~typing.Any] = <factory>, http_header: ~typing.Dict[str, ~typing.Any] = <factory>, encoding: str = 'latin-1', name: ~typing.Optional[str] = None)

  Metadata for a pipe.

  __init__(domain_record: ~Processor.App.processor_utils.DomainRecord, article_data: ~typing.Dict[~typing.Any, ~typing.Any] = <factory>, warc_header: ~typing.Dict[str, ~typing.Any] = <factory>, http_header: ~typing.Dict[str, ~typing.Any] = <factory>, encoding: str = 'latin-1', name: ~typing.Optional[str] = None) → None

  Methods

  `__init__`(domain_record[, article_data, ...]) |

  Attributes

  `encoding` |
  `name` |
  `domain_record` |
  `article_data` |
  `warc_header` |
  `http_header` |